<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="39"/>
        <source>Row</source>
        <translation>Fila</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="40"/>
        <source>Column</source>
        <translation>Columna</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="41"/>
        <source>Characters %1</source>
        <translation>Caracteres %1</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="300"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="344"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="201"/>
        <location filename="../src/editor/editwrapper.cpp" line="264"/>
        <location filename="../src/editor/editwrapper.cpp" line="321"/>
        <location filename="../src/editor/editwrapper.cpp" line="536"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="316"/>
        <source>Do you want to save this file?</source>
        <translation>¿Desea guardar este archivo?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="262"/>
        <location filename="../src/editor/editwrapper.cpp" line="319"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="259"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation>La codificación ha cambiado. ¿Desea guardar el archivo ahora?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="320"/>
        <source>Discard</source>
        <translation>Descartar</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="445"/>
        <source>You do not have permission to save %1</source>
        <translation>No tienes permisos para guardar %1</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="607"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>Archivo eliminado en el disco. ¿Desea guardarlo?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="612"/>
        <source>File has changed on disk. Reload?</source>
        <translation>El archivo ha cambiado en el disco. ¿Recargar?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="634"/>
        <location filename="../src/widgets/bottombar.cpp" line="60"/>
        <source>INSERT</source>
        <translation>INSERTAR</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="637"/>
        <source>OVERWRITE</source>
        <translation>SOBRESCRIBIR</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="640"/>
        <source>R/O</source>
        <translation>R/O</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="40"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="44"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="46"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="40"/>
        <source>Go to Line: </source>
        <translation>Ir a la línea</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="27"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>Editor de texto de Deepin es una poderosa herramienta para ver y editar archivos de texto.</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="38"/>
        <source>Text Editor</source>
        <translation>Editor de texto</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="35"/>
        <source>Text Editor</source>
        <translation>Editor de texto</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="203"/>
        <location filename="../src/editor/editwrapper.cpp" line="538"/>
        <location filename="../src/widgets/window.cpp" line="956"/>
        <location filename="../src/widgets/window.cpp" line="973"/>
        <location filename="../src/widgets/window.cpp" line="1064"/>
        <location filename="../src/widgets/window.cpp" line="1079"/>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Font Style</source>
        <translation>Estilo de fuente</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Font Size</source>
        <translation>Tamaño de fuente</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Keymap</source>
        <translation>Asignación de teclas</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <location filename="../src/widgets/window.cpp" line="1482"/>
        <source>Window</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>New tab</source>
        <translation>Nueva pestaña</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>New window</source>
        <translation>Nueva ventana</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Next tab</source>
        <translation>Pestaña siguiente</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Previous tab</source>
        <translation>Pestaña anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Close tab</source>
        <translation>Cerrar pestaña</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Close other tabs</source>
        <translation>Cerrar otras pestañas</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Restore tab</source>
        <translation>Restaurar pestaña </translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Increment font size</source>
        <translation>Aumentar tamaño de letra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Decrement font size</source>
        <translation>Disminuir tamaño de letra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Reset font size</source>
        <translation>Restablecer tamaño de la letra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Toggle fullscreen</source>
        <translation>Cambiar a pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Go to line</source>
        <translation>Ir a la línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Save cursor position</source>
        <translation>Guardar la posición del cursor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>Reset cursor position</source>
        <translation>Restablecer posición del cursor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Increase indent</source>
        <translation>Aumentar sangría</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Decrease indent</source>
        <translation>Disminuir sangría</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Forward character</source>
        <translation>Próximo carácter</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Backward character</source>
        <translation>Carácter anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Forward word</source>
        <translation>Próxima palabra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Backward word</source>
        <translation>Palabra anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Next line</source>
        <translation>Siguiente línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Previous line</source>
        <translation>Línea anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>New line</source>
        <translation>Nueva línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>New line above</source>
        <translation>Nueva línea encima</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>New line below</source>
        <translation>Nueva línea debajo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Duplicate line</source>
        <translation>Duplicar línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Delete to end of line</source>
        <translation>Borrar hasta el final de la línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Delete current line</source>
        <translation>Borrar la línea actual</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Swap line up</source>
        <translation>Subir línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Swap line down</source>
        <translation>Bajar línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Scroll up one line</source>
        <translation>Desplazar una línea arriba</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Scroll down one line</source>
        <translation>Desplazar una línea abajo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Page up</source>
        <translation>Página arriba</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Page down</source>
        <translation>Página abajo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Move to end of line</source>
        <translation>Mover al final de la línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Move to start of line</source>
        <translation>Mover al inicio de la línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Move to end of text</source>
        <translation>Mover al final del texto</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Move to start of text</source>
        <translation>Mover al inicio del texto</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Move to line indentation</source>
        <translation>Mover a sangría de línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Upper case</source>
        <translation>Mayúsculas</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Lower case</source>
        <translation>Minúsculas</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Capitalize</source>
        <translation>Capitalizar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Delete backward word</source>
        <translation>Borrar palabra anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Delete forward word</source>
        <translation>Borrar siguiente palabra</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Forward over a pair</source>
        <translation>Adelantar sobre un par</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Backward over a pair</source>
        <translation>Retroceder sobre un par</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Select all</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Transpose character</source>
        <translation>Transponer carácter</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Mark</source>
        <translation>Resaltar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <source>Unmark</source>
        <translation>No resaltar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Copy line</source>
        <translation>Copiar línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Cut line</source>
        <translation>Cortar línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Merge lines</source>
        <translation>Fusionar líneas</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="98"/>
        <source>Read-Only mode</source>
        <translation>Modo solo lectura</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Add comment</source>
        <translation>Añadir comentario</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Remove comment</source>
        <translation>Borrar comentario</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="101"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="103"/>
        <source>Add/Remove bookmark</source>
        <translation>Añadir/quitar marcador</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Move to previous bookmark</source>
        <translation>Mover al marcador anterior</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Move to next bookmark</source>
        <translation>Mover al siguiente marcador</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Window size</source>
        <translation>Tamaño de ventana</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Tab width</source>
        <translation>Ancho de la pestaña</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="111"/>
        <source>Word wrap</source>
        <translation>Ajuste de línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="112"/>
        <source>Code folding flag</source>
        <translation>Marcador para contraer el código</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Show line numbers</source>
        <translation>Mostrar número de línea</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>Show bookmarks icon</source>
        <translation>Mostrar iconos de marcadores</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>Show whitespaces and tabs</source>
        <translation>Mostrar espacios en blanco y tabulaciones</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Highlight current line</source>
        <translation>Resaltar línea actual</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Color mark</source>
        <translation>Resaltador</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>WesternEuropean</source>
        <translation>Europeo Occidental</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>CentralEuropean</source>
        <translation>Centro Europeo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Baltic</source>
        <translation>Báltico</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>Cyrillic</source>
        <translation>Cirílico</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>Arabic</source>
        <translation>Árabe</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="130"/>
        <source>Celtic</source>
        <translation>Céltico</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="131"/>
        <source>SouthEasternEuropean</source>
        <translation>Europeo del Sudeste</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>Greek</source>
        <translation>Griego</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Hebrew</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="132"/>
        <source>ChineseSimplified</source>
        <translation>Chino Simplificado</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="133"/>
        <source>ChineseTraditional</source>
        <translation>Chino Tradicional</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="134"/>
        <source>Japanese</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="135"/>
        <source>Korean</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Thai</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Turkish</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="136"/>
        <source>Vietnamese</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <location filename="../src/startmanager.cpp" line="762"/>
        <source>File not saved</source>
        <translation>No se guardó el archivo</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="974"/>
        <location filename="../src/widgets/window.cpp" line="1065"/>
        <location filename="../src/widgets/window.cpp" line="1080"/>
        <source>Line Endings</source>
        <translation>Finales de línea</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="39"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="43"/>
        <source>Replace With</source>
        <translation>Reemplazar con</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="47"/>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="50"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="53"/>
        <source>Replace Rest</source>
        <translation>Reemplazar el resto</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="56"/>
        <source>Replace All</source>
        <translation>Reemplazar todo</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../third/libiconv-1.16/src/iconv.c" line="103"/>
        <source/>
        <comment>The first line of the short usage message.</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Standard</source>
        <translation>Estándar</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Customize</source>
        <translation>Personalizar</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Maximum</source>
        <translation>Maximizada</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="292"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation>Este atajo entra en conflicto con el atajo del sistema %1</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="294"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation>Este atajo entra en conflicto con %1, haga clic en Reemplazar para que este atajo sea efectivo inmediatamente</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="410"/>
        <location filename="../src/common/settings.cpp" line="418"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation>El atajo %1 es inválido, por favor ponga otro.</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="445"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="446"/>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="448"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="340"/>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="515"/>
        <source>Close tab</source>
        <translation>Cerrar pestaña</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="516"/>
        <source>Close other tabs</source>
        <translation>Cerrar otras pestañas</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="517"/>
        <source>More options</source>
        <translation>Más opciones</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="518"/>
        <source>Close tabs to the left</source>
        <translation>Cerrar las pestañas de la izquierda</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="519"/>
        <source>Close tabs to the right</source>
        <translation>Cerrar las pestañas de la derecha</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="520"/>
        <source>Close unmodified tabs</source>
        <translation>Cerrar las pestañas sin modificar</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="235"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="236"/>
        <source>Redo</source>
        <translation>Rehacer</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="237"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="238"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="239"/>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="240"/>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="241"/>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="242"/>
        <location filename="../src/widgets/window.cpp" line="361"/>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="243"/>
        <location filename="../src/widgets/window.cpp" line="362"/>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="244"/>
        <source>Go to Line</source>
        <translation>Ir a la línea</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="245"/>
        <source>Turn on Read-Only mode</source>
        <translation>Activar modo solo lectura</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="246"/>
        <source>Turn off Read-Only mode</source>
        <translation>Desactivar modo solo lectura</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="248"/>
        <source>Exit fullscreen</source>
        <translation>Salir de la pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="249"/>
        <source>Display in file manager</source>
        <translation>Mostrar en el administrador de archivos</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="250"/>
        <location filename="../src/editor/dtextedit.cpp" line="302"/>
        <source>Add Comment</source>
        <translation>Añadir comentario</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="251"/>
        <source>Text to Speech</source>
        <translation>Texto a voz</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="252"/>
        <source>Stop reading</source>
        <translation>Detener lectura</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="253"/>
        <source>Speech to Text</source>
        <translation>Voz a texto</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="254"/>
        <source>Translate</source>
        <translation>Traducir</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="255"/>
        <source>Column Mode</source>
        <translation>Modo de columna</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="256"/>
        <source>Add bookmark</source>
        <translation>Añadir marcador</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="257"/>
        <source>Remove Bookmark</source>
        <translation>Quitar marcador</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="258"/>
        <source>Previous bookmark</source>
        <translation>Marcador anterior</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="259"/>
        <source>Next bookmark</source>
        <translation>Marcador siguiente</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="260"/>
        <source>Remove All Bookmarks</source>
        <translation>Quitar todos los marcadores</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="261"/>
        <source>Fold All</source>
        <translation>Ocultar todo</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="262"/>
        <source>Fold Current Level</source>
        <translation>Ocultar el nivel actual</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="263"/>
        <source>Unfold All</source>
        <translation>Mostrar todo</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="264"/>
        <source>Unfold Current Level</source>
        <translation>Mostrar el nivel actual</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="269"/>
        <source>Color Mark</source>
        <translation>Resaltador</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Clear All Marks</source>
        <translation>Borrar todo lo resaltado</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Clear Last Mark</source>
        <translation>Borrar último resalte</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Mark</source>
        <translation>Resaltar</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Mark All</source>
        <translation>Resaltar todo</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="303"/>
        <source>Remove Comment</source>
        <translation>Borrar comentario</translation>
    </message>
    <message>
        <source>Failed to paste text: it is too large</source>
        <translation type="vanished">Fallo al pegar el texto: es demasiado grande</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2581"/>
        <source>Copy failed: not enough memory</source>
        <translation>Copia fallida: no hay suficiente memoria</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2665"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation>Presiona ALT y haz clic en las líneas para editar en el modo de columna</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="346"/>
        <source>Change Case</source>
        <translation>Formato de texto</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="347"/>
        <source>Upper Case</source>
        <translation>Mayúsculas</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="348"/>
        <source>Lower Case</source>
        <translation>Minúsculas</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="349"/>
        <source>Capitalize</source>
        <translation>Capitalizar</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="64"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1184"/>
        <source>Selected line(s) copied</source>
        <translation>Líneas seleccionadas copiadas</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1190"/>
        <source>Current line copied</source>
        <translation>Línea actual copiada</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1210"/>
        <source>Selected line(s) clipped</source>
        <translation>Líneas seleccionadas cortadas</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1222"/>
        <source>Current line clipped</source>
        <translation>Línea actual cortada</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2591"/>
        <source>Paste failed: not enough memory</source>
        <translation>Fallo al pegar: no hay suficiente memoria</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3439"/>
        <source>Read-Only mode is off</source>
        <translation>Modo solo lectura desactivado</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3446"/>
        <location filename="../src/editor/dtextedit.cpp" line="3465"/>
        <location filename="../src/editor/dtextedit.cpp" line="6150"/>
        <source>Read-Only mode is on</source>
        <translation>Modo solo lectura activado</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="36"/>
        <source>Reload</source>
        <translation>Recargar</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="38"/>
        <location filename="../src/widgets/window.cpp" line="357"/>
        <source>Save as</source>
        <translation>Guardar como</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="353"/>
        <source>New window</source>
        <translation>Nueva ventana</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="354"/>
        <source>New tab</source>
        <translation>Nueva pestaña</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="355"/>
        <source>Open file</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="356"/>
        <location filename="../src/widgets/window.cpp" line="2217"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="358"/>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="359"/>
        <source>Switch theme</source>
        <translation>Cambiar el tema</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="360"/>
        <location filename="../src/widgets/window.cpp" line="1542"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="471"/>
        <location filename="../src/widgets/window.cpp" line="2468"/>
        <source>Read-Only</source>
        <translation>Sólo lectura</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <source>You do not have permission to open %1</source>
        <translation>No tienes permisos para abrir %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="522"/>
        <source>Invalid file: %1</source>
        <translation>Archivo inválido: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="602"/>
        <location filename="../src/widgets/window.cpp" line="644"/>
        <source>Do you want to save this file?</source>
        <translation>¿Desea guardar este archivo?</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="894"/>
        <source>You do not have permission to save %1</source>
        <translation>No tienes permisos para guardar %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="918"/>
        <source>Saved successfully</source>
        <translation>Guardado exitosamente</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="954"/>
        <location filename="../src/widgets/window.cpp" line="1021"/>
        <location filename="../src/widgets/window.cpp" line="1062"/>
        <source>Save File</source>
        <translation>Guardar el archivo</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1023"/>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1211"/>
        <source>Read-Only mode is on</source>
        <translation>Modo solo lectura activado</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1441"/>
        <source>Current location remembered</source>
        <translation>Guardar ubicación actual</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1492"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation>Ctrl+&apos;=&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1495"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation>Ctrl+&apos;-&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1524"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1890"/>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2215"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2216"/>
        <source>Discard</source>
        <translation>Descartar</translation>
    </message>
</context>
</TS>